@@ -10,20 +10,37 @@ local_tz = get_localzone()  # get the local timezone
 
 _IGLU_R_COMPATIBLE = True
 
+
 def set_iglu_r_compatible(value: bool) -> None:
     global _IGLU_R_COMPATIBLE
     _IGLU_R_COMPATIBLE = value
 
+
 def is_iglu_r_compatible() -> bool:
     global _IGLU_R_COMPATIBLE
     return _IGLU_R_COMPATIBLE
 
+
 def localize_naive_timestamp(timestamp: datetime) -> datetime:
     """
     Localize a naive timestamp to the local timezone.
     """
     if timestamp.tzinfo is None:
-        return timestamp.tz_localize(local_tz)
+        # Handle ambiguous times (e.g., DST transitions) by specifying 'ambiguous' argument
+        # Default to 'NaT' for ambiguous times, but you may choose 'raise' or 'infer' as needed
+        return timestamp.tz_localize(local_tz, ambiguous="NaT")
+    else:
+        return timestamp
+
+
+def localize_naive_timestamp_to_UTC(timestamp: datetime) -> datetime:
+    """
+    Localize a naive timestamp to the UTC timezone.
+    """
+    if timestamp.tzinfo is None:
+        # Handle ambiguous times (e.g., DST transitions) by specifying 'ambiguous' argument
+        # Default to 'NaT' for ambiguous times, but you may choose 'raise' or 'infer' as needed
+        return timestamp.tz_localize("UTC")
     else:
         return timestamp
 
@@ -36,7 +53,8 @@ def set_local_tz(tz: str) -> None:
     global local_tz
     local_tz = ZoneInfo(tz)
 
-def get_local_tz() :
+
+def get_local_tz():
     global local_tz
     return local_tz
 
@@ -52,6 +70,7 @@ def check_data_columns(data: pd.DataFrame, time_check=False, tz="") -> pd.DataFr
     tz : str, default=""
         Time zone to use for calculations
         If tz is not "", the time column is converted to the specified timezone
+        if tz is "", the time column is converted to UTC timezone
 
     Returns
     -------
@@ -114,13 +133,16 @@ def check_data_columns(data: pd.DataFrame, time_check=False, tz="") -> pd.DataFr
         data["time"] = pd.to_datetime(data["time"]).apply(localize_naive_timestamp).dt.tz_convert(tz)
     else:
         # Create a copy to avoid dtype warning
-        data["time"] = pd.to_datetime(data["time"]).apply(localize_naive_timestamp)
+        data["time"] = pd.to_datetime(data["time"]).apply(localize_naive_timestamp_to_UTC)
+
+    # Drop rows where 'time' is NaT
+    data = data[~pd.isna(data["time"])]
 
     return data
 
 
-def CGMS2DayByDay(
-    data: pd.DataFrame|pd.Series,
+def CGMS2DayByDay(  # noqa: C901
+    data: pd.DataFrame | pd.Series,
     dt0: Optional[pd.Timestamp] = None,
     inter_gap: int = 45,
     tz: str = "",
@@ -190,14 +212,16 @@ def CGMS2DayByDay(
     if dt0 is None:
         # Use most common time difference
         time_diffs = data["time"].diff().dropna()
-        dt0 = int(time_diffs.mode().iloc[0].total_seconds() / 60)
+        # Only consider time differences >= 1 minute when computing the mode
+        time_diffs_filtered = time_diffs[time_diffs.dt.total_seconds() >= 60]
+        if len(time_diffs_filtered) == 0:
+            raise ValueError("No time differences >= 1 minute found to compute dt0.")
+        dt0 = int(time_diffs_filtered.mode().iloc[0].total_seconds() / 60)
 
     # Create time grid
     start_time = data["time"].min().floor("D")
     end_time = data["time"].max().ceil("D")
-    time_grid = pd.date_range(
-        start=start_time, end=end_time, freq=f"{dt0}min"
-    )
+    time_grid = pd.date_range(start=start_time, end=end_time, freq=f"{dt0}min")
     if is_iglu_r_compatible():
         # remove the first time point
         time_grid = time_grid[1:]
@@ -208,12 +232,18 @@ def CGMS2DayByDay(
     # find gaps in the data (using original data indexes, not time grid)
     gaps = []
     for i in range(len(data) - 1):
-        if (
-            data["time"].iloc[i + 1] - data["time"].iloc[i]
-        ).total_seconds() > inter_gap * 60:
+        if (data["time"].iloc[i + 1] - data["time"].iloc[i]).total_seconds() > inter_gap * 60:
             gaps.append((i, i + 1))
 
     # Interpolate glucose values
+    # Note: doesn't work right with DST crossings
+    # During DST spring forward (March 12, 2023)
+    # 2:00 AM → 3:00 AM (hour is skipped)
+    # Your current code would try to interpolate:
+    # 2:30 AM → ??? (this time doesn't exist!)
+    # np.interp will linearly interpolate between 2:00 AM and 3:00 AM
+    # giving you a glucose value for a non-existent time
+    # TODO: fix this
     interp_data = np.interp(
         (time_grid - start_time).total_seconds() / 60,
         (data["time"] - start_time).dt.total_seconds() / 60,
@@ -227,15 +257,14 @@ def CGMS2DayByDay(
         gap_start_idx = gap[0]
         gap_start_time = data["time"].iloc[gap_start_idx]
         # find the index of the gap start in the time grid
-        gap_start_idx_in_time_grid = int(
-            np.floor((gap_start_time - start_time).total_seconds() / (60 * dt0))
-        )
+        gap_start_idx_in_time_grid = int(np.floor((gap_start_time - start_time).total_seconds() / (60 * dt0)))
         gap_end_idx = gap[1]
         gap_end_time = data["time"].iloc[gap_end_idx]
         # find the index of the gap end in the time grid
         gap_end_idx_in_time_grid = int(
             # -1sec to indicate time before measurement
-            np.floor(((gap_end_time - start_time).total_seconds() -1 ) / (60 * dt0)))
+            np.floor(((gap_end_time - start_time).total_seconds() - 1) / (60 * dt0))
+        )
         # put nan in the gap
         interp_data[gap_start_idx_in_time_grid:gap_end_idx_in_time_grid] = np.nan
 
@@ -249,6 +278,16 @@ def CGMS2DayByDay(
     # Reshape to days
     n_days = (end_time - start_time).days
     n_points_per_day = 24 * 60 // dt0
+
+    # workaround for misalignment, probably due to DST crossings
+    # ToDo: fix it!
+    if interp_data.shape[0] != n_days * n_points_per_day:
+        # cut or pad interp_data to n_days*n_point_per_day
+        target_size = n_days * n_points_per_day
+        if interp_data.shape[0] > target_size:
+            interp_data = interp_data[:target_size]
+        elif interp_data.shape[0] < target_size:
+            interp_data = np.pad(interp_data, (0, target_size - interp_data.shape[0]), constant_values=np.nan)
     interp_data = interp_data.reshape(n_days, n_points_per_day)
 
     # Get actual dates
@@ -260,6 +299,7 @@ def CGMS2DayByDay(
 
     return interp_data, actual_dates, dt0
 
+
 def gd2d_to_df(gd2d, actual_dates, dt0):
     """Convert gd2d (CGMS2DayByDay output) to a pandas DataFrame"""
     df = pd.DataFrame({"time": [], "gl": []})
@@ -271,9 +311,6 @@ def gd2d_to_df(gd2d, actual_dates, dt0):
         day_time = [pd.Timedelta(i * dt0, unit="m") + actual_dates[day] for i in range(n)]
         time.extend(day_time)
 
-    df = pd.DataFrame({
-            "time": pd.Series(time),
-            "gl": pd.Series(gl, dtype='float64')
-        })
+    df = pd.DataFrame({"time": pd.Series(time), "gl": pd.Series(gl, dtype="float64")})
 
     return df
